.frame-child {
  position: relative;
  width: 200px;
  height: 75px;
}
.frame {
  border-radius: 30px;
  border: 1px solid var(--color-blue);
  background-color: var(--color-white);
  width: 520px;
  height: 630px;
  overflow: hidden;
  flex-shrink: 0;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: flex-start;
  padding: 58px 0;
  box-sizing: border-box;
}
.frame-icon {
  position: absolute;
  top: 0;
  left: 116px;
  width: 168px;
  height: 73px;
  overflow: hidden;
}
.fyers-configuration-settings {
  position: absolute;
  top: 92px;
  left: 35px;
  font-size: 20px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 350px;
  height: 50px;
}
.app-id {
  position: relative;
  display: flex;
  align-items: center;
  width: 112px;
  height: 20px;
  flex-shrink: 0;
}
.frame-item {
  position: relative;
  border-radius: var(--br-3xs);
  border: 1px solid var(--color-blue); 
  background-color: var(--color-white);
  width: 400px;
  height: 50px;
}
.app-id-parent,
.frame-parent {
  display: flex;
  flex-direction: column;
}
.app-id-parent {
  width: 400px;
  align-items: flex-start;
  justify-content: flex-start;
}
.frame-parent {
  position: absolute;
  top: 160px;
  left: 0;
  align-items: center;
  justify-content: center;
  gap: 25px;
  text-align: left;
}
.frame-child1 {
  position: relative;
  border-radius: var(--br-3xs);
  background: linear-gradient(180deg, #fff, rgba(255, 255, 255, 0));
  width: 120px;
  height: 30px;
}
.frame3,
.save {
  display: flex;
  justify-content: center;
}
.frame3 {
  width: 400px;
  overflow: hidden;
  flex-direction: column;
  align-items: flex-end;
}
.save {
  position: relative;
  align-items: center;
  width: 120px;
  height: 30px;
  flex-shrink: 0;
  border: 1px solid var(--color-blue); 
  border-radius: 10px;
}
.frame2,
.frame4 {
  width: 400px;
  overflow: hidden;
  display: flex;
  flex-direction: column;
}
.frame4 {
  align-items: flex-end;
  justify-content: center;
  margin-top: -30px;
}
button {
  background-color: var(--color-white);
}
.frame2 {
  position: absolute;
  top: 483px;
  left: 0;
  align-items: center;
  justify-content: flex-start;
}
.desktop-1,
.frame1 {
  position: relative;
  z-index: 10;

}
.frame1 {
  width: 400px;
  height: 569px;
  flex-shrink: 0;
  margin-top: -570px;
}
body {
  background-color: #fcfcfc;
}
.desktop-1 {
  background-color: #fcfcfc;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: flex-end;
  padding: 135px 460px;
  box-sizing: border-box;
  text-align: center;
  font-size: var(--font-size-3xs);
  color: var(--color-black);
  font-family: var(--font-inter);
}

input {
  position: relative;
  width: 380px;
  left: 10px;
  top: 5px;
  height: 40px;
  border:0px;
  outline: none;
}
