<!DOCTYPE html>
<html>
 <head>
   <meta charset="utf-8" />
   <meta name="viewport" content="initial-scale=1, width=device-width" />
   <link rel="stylesheet" href="{{ url_for('static', filename='css/config_index.css') }}" />
   <link rel="stylesheet" href="{{ url_for('static', filename='css/config_global.css') }}" />
   <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Inter:wght@400&display=swap" />
 </head>
 <body>
     {% for message in get_flashed_messages() %}
         <div class="alert">{{ message }}</div>
    {% endfor %}

   <div class="desktop-1">
     <div class="frame">
       <div class="frame-child"></div>
     </div>
     <div class="frame1">
       <form method="POST">
         <img class="frame-icon" alt="" src="{{ url_for('static', filename='images/config_logo.svg') }}" />
         <div class="fyers-configuration-settings">
           Fyers Helper Configuration Settings
         </div>
         <div class="frame-parent">
           <div class="app-id-parent">
             <div class="app-id">APP ID</div>
             <div class="frame-item"><input type='text' name='app_id'></div>
           </div>
           <div class="app-id-parent">
             <div class="app-id">SECRET ID</div>
             <div class="frame-item"><input type='text' name='secret_id'></div>
           </div>
           <div class="app-id-parent">
             <div class="app-id">REDIRECT URL</div>
             <div class="frame-item"><input type='text' name='redirect_url'></div>
           </div>
         </div>
         <div class="frame2">
           <div class="frame3">
             <div class="frame-child1"></div>
           </div>
           <div class="frame4">
             <button class="save" type="submit">Save</button>
           </div>
         </div>
       </form>
     </div>
   </div>
 </body>
</html>
